@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001 FUKUCHI Kentarou
+ * Copyright (C) 2001-2003 FUKUCHI Kentaro
  *
  * buffer.c: shared buffer manager
  *
@@ -28,6 +28,11 @@ int sharedbuffer_init()
 		return 0;
 }
 
+void sharedbuffer_end()
+{
+	free(sharedbuffer);
+}
+
 /* The effects uses shared buffer must call this function at first in
  * each effect registrar.
  */
