@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001 FUKUCHI Kentarou
+ * Copyright (C) 2001-2003 FUKUCHI Kentaro
  *
  * cycleTV - no effect.
  * Written by clifford smith <nullset@dookie.net>
@@ -9,16 +9,17 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include "../EffecTV.h"
+#include "EffecTV.h"
 #include "utils.h"
 
-int cycleStart();
-int cycleStop();
-int cycleDraw();
+static int start(void);
+static int stop(void);
+static int draw(RGB32 *src, RGB32 *dst);
 
 static char *effectname = "cycleTV";
 static int state = 0;
-int roff,goff,boff; /* Offset values */
+static int roff,goff,boff; /* Offset values */
+
 effect *cycleRegister()
 {
 	effect *entry;
@@ -27,45 +28,31 @@ effect *cycleRegister()
 	if(entry == NULL) return NULL;
 	
 	entry->name = effectname;
-	entry->start = cycleStart;
-	entry->stop = cycleStop;
-	entry->draw = cycleDraw;
+	entry->start = start;
+	entry->stop = stop;
+	entry->draw = draw;
 	entry->event = NULL;
 
 	return entry;
 }
 
-int cycleStart()
+static int start()
 {
-  roff = goff = boff = 0;
-	if(video_grabstart())
-		return -1;
+	roff = goff = boff = 0;
 	state = 1;
 	return 0;
 }
 
-int cycleStop()
+static int stop()
 {
-	if(state) {
-		video_grabstop();
-		state = 0;
-	}
-
+	state = 0;
 	return 0;
 }
 
 #define NEWCOLOR(c,o) ((c+o)%230)
-int cycleDraw()
+static int draw(RGB32 *src, RGB32 *dst)
 {
   int i;
-  RGB32 *src,*dst;
-  
-  src = (RGB32 *)video_getaddress();
-  if (stretch) {
-    dst = stretching_buffer;
-  } else {
-    dst = (RGB32 *)screen_getaddress();
-  }
   
   roff += 1;
   goff += 3;        
@@ -73,13 +60,6 @@ int cycleDraw()
     image_stretch_to_screen();
   
   boff += 7;
-  if(video_syncframe())
-    return -1;
-  if(screen_mustlock()) {
-    if(screen_lock() < 0) {
-      return video_grabframe();
-    }
-  }
   for (i=0 ; i < video_area ; i++) {
     RGB32 t;
     t = *src++;
@@ -88,14 +68,6 @@ int cycleDraw()
 	       NEWCOLOR(BLUE(t),boff));
   }
 
-  
-  if(screen_mustlock()) {
-    screen_unlock();
-  }
-  
-  if(video_grabframe())
-    return -1;
-  
   return 0;
 }
 
