@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001 FUKUCHI Kentarou
+ * Copyright (C) 2001-2003 FUKUCHI Kentaro
  *
  * screen.h: header for screen manager
  *
@@ -22,18 +22,20 @@ extern int screen_scale;
 
 /* description of these functions are in screen.c */
 int screen_init(int w, int h, int s);
-void screen_quit();
-int screen_bpp();
+void screen_quit(void);
+int screen_bpp(void);
 void screen_setcaption(const char *str);
 void screen_clear(int color);
-void screen_fullscreen();
+void screen_fullscreen(void);
+int screen_lock(void);
+void screen_unlock(void);
 
 /* Returns memory address of the frame buffer. The value may be changed every drawing
  * phase. You have to call this function at the begining of draw function of effects. */
 #ifndef RGB_BGR_CONVERSION
 #define screen_getaddress() (screen->pixels)
 #else
-unsigned char *screen_getaddress();
+unsigned char *screen_getaddress(void);
 #endif
 
 /* This function must be called when the effects fished their drawing phase.
@@ -41,17 +43,7 @@ unsigned char *screen_getaddress();
 #ifndef RGB_BGR_CONVERSION
 #define screen_update() (SDL_Flip(screen))
 #else
-int screen_update();
+int screen_update(void);
 #endif
 
-/* If this function returns non-zero, you have to call screen_lock before access
- * the frame buffer. */
-#define screen_mustlock() (SDL_MUSTLOCK(screen))
-
-/* Lock the frame buffer */
-#define screen_lock() (SDL_LockSurface(screen))
-
-/* Unlock the frame buffer */
-#define screen_unlock() (SDL_UnlockSurface(screen))
-
 #endif /* __SCREEN_H__ */
